{
	name               => 'TestApp',
	Controller::Config => {
		foo => 'foo'
	},
	cache              => '__HOME__/cache',
}
